@@ -4,7 +4,7 @@ our $AUTHORITY = 'cpan:GENE';
 use Moo;
 use POSIX qw( ceil );
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use constant K => 3.14159265358979323846 / 180;
 
@@ -153,12 +153,9 @@ sub forward {
     $self->x( $x + $xo );
     $self->y( $y + $yo );
 
-    if ( $self->pen_status == 1 ) {
-        return
-            ceil($xo), ceil($yo),
-            ceil($self->x), ceil($self->y),
-            $self->pen_color, $self->pen_size;
-    }
+    return $self->pen_status == 1
+        ? ( ceil($xo), ceil($yo), ceil($self->x), ceil($self->y), $self->pen_color, $self->pen_size )
+        : undef;
 }
 
 
@@ -185,12 +182,9 @@ sub goto {
     $self->x($x);
     $self->y($y);
 
-    if ( $self->pen_status == 1 ) {
-        return
-            ceil($xo), ceil($yo),
-            ceil($self->x), ceil($self->y),
-            $self->pen_color, $self->pen_size;
-    }
+    return $self->pen_status == 1
+        ? ( ceil($xo), ceil($yo), ceil($self->x), ceil($self->y), $self->pen_color, $self->pen_size )
+        : undef;
 }
 
 1;
@@ -207,7 +201,7 @@ Data::Turtle
 
 =head1 VERSION
 
-version 0.0105
+version 0.0106
 
 =head1 SYNOPSIS
 
@@ -233,8 +227,8 @@ version 0.0105
 This module enables basic turtle movement and state operations without requiring
 any particular graphics package.
 
-The methods don't draw anything per se.  They set or output coordinates and
-values for line drawing by your favorite graphics package.
+The methods don't draw anything.  They just set or output coordinates and
+values for drawing by your favorite graphics package.
 
 Please see the F<eg/> distribution directory for example code, with L<GD> and
 L<Imager>.
@@ -380,6 +374,8 @@ Move the pen to the given coordinate.
 
 L<https://metacpan.org/source/YVESP/llg-1.07/Turtle.pm>
 
+L<https://en.wikipedia.org/wiki/Turtle_graphics>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
